==> XeniumIO_0.99.4.tar.gz: XeniumIO/inst/doc/XeniumIO.R <==
## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(cache = TRUE)

## ----eval=FALSE---------------------------------------------------------------
# BiocManager::install("Bioconductor/XeniumIO")

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(XeniumIO)

## ----eval=FALSE---------------------------------------------------------------
# TENxXenium(
#     resources = "path/to/matrix/folder/or/file",
#     xeniumOut = "path/to/xeniumOut/folder",
#     sample_id = "sample01",
#     format = c("mtx", "h5"),
#     boundaries_format = c("parquet", "csv.gz"),
#     spatialCoordsNames = c("x_centroid", "y_centroid"),
#     ...
# )

## -----------------------------------------------------------------------------
showClass("TENxXenium")

## -----------------------------------------------------------------------------
getMethod("import", c(con = "TENxXenium"))

## -----------------------------------------------------------------------------
destfile <- XeniumIO:::.cache_url_file(
    url = paste0(
        "https://cf.10xgenomics.com/samples/xenium/3.0.0/",
        "Xenium_Prime_MultiCellSeg_Mouse_Ileum_tiny/",
        "Xenium_Prime_MultiCellSeg_Mouse_Ileum_tiny_outs.zip"
    )
)
outfile <- file.path(
    tempdir(), "Xenium_Prime_MultiCellSeg_Mouse_Ileum_tiny_outs"
)
if (!dir.exists(outfile))
    dir.create(outfile, recursive = TRUE)
unzip(
    zipfile = destfile, exdir = outfile, overwrite = FALSE
)
TENxXenium(xeniumOut = outfile) |>
    import()

## -----------------------------------------------------------------------------
sessionInfo()

==> XeniumIO_0.99.5.tar.gz: XeniumIO/inst/doc/XeniumIO.R <==
## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(cache = TRUE)

## ----eval=FALSE---------------------------------------------------------------
# BiocManager::install("Bioconductor/XeniumIO")

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(XeniumIO)

## ----eval=FALSE---------------------------------------------------------------
# TENxXenium(
#     resources = "path/to/matrix/folder/or/file",
#     xeniumOut = "path/to/xeniumOut/folder",
#     sample_id = "sample01",
#     format = c("mtx", "h5"),
#     boundaries_format = c("parquet", "csv.gz"),
#     spatialCoordsNames = c("x_centroid", "y_centroid"),
#     ...
# )

## -----------------------------------------------------------------------------
showClass("TENxXenium")

## -----------------------------------------------------------------------------
getMethod("import", c(con = "TENxXenium"))

## -----------------------------------------------------------------------------
zipfile <- paste0(
    "https://mghp.osn.xsede.org/bir190004-bucket01/BiocXenDemo/",
    "Xenium_Prime_MultiCellSeg_Mouse_Ileum_tiny_outs.zip"
)
destfile <- XeniumIO:::.cache_url_file(zipfile)
outfold <- file.path(
    tempdir(), tools::file_path_sans_ext(basename(zipfile))
)
if (!dir.exists(outfold))
    dir.create(outfold, recursive = TRUE)
unzip(
    zipfile = destfile, exdir = outfold, overwrite = FALSE
)
TENxXenium(xeniumOut = outfold) |>
    import()

## -----------------------------------------------------------------------------
sessionInfo()
